# Generated by Django 2.0 on 2018-01-08 07:06

import cities.models
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cities', '0010_adjust_unique_attributes'),
    ]

    operations = [
        migrations.AlterField(
            model_name='city',
            name='country',
            field=models.ForeignKey(on_delete=cities.models.SET_NULL_OR_CASCADE, related_name='cities', to=settings.CITIES_COUNTRY_MODEL),
        ),
        migrations.AlterField(
            model_name='city',
            name='region',
            field=models.ForeignKey(blank=True, null=True, on_delete=cities.models.SET_NULL_OR_CASCADE, related_name='cities', to='cities.Region'),
        ),
        migrations.AlterField(
            model_name='city',
            name='subregion',
            field=models.ForeignKey(blank=True, null=True, on_delete=cities.models.SET_NULL_OR_CASCADE, related_name='cities', to='cities.Subregion'),
        ),
        migrations.AlterField(
            model_name='country',
            name='continent',
            field=models.ForeignKey(null=True, on_delete=cities.models.SET_NULL_OR_CASCADE, related_name='countries', to=settings.CITIES_CONTINENT_MODEL),
        ),
        migrations.AlterField(
            model_name='district',
            name='city',
            field=models.ForeignKey(on_delete=cities.models.SET_NULL_OR_CASCADE, related_name='districts', to=settings.CITIES_CITY_MODEL),
        ),
        migrations.AlterField(
            model_name='postalcode',
            name='city',
            field=models.ForeignKey(blank=True, null=True, on_delete=cities.models.SET_NULL_OR_CASCADE, related_name='postal_codes', to=settings.CITIES_CITY_MODEL),
        ),
        migrations.AlterField(
            model_name='postalcode',
            name='district',
            field=models.ForeignKey(blank=True, null=True, on_delete=cities.models.SET_NULL_OR_CASCADE, related_name='postal_codes', to='cities.District'),
        ),
        migrations.AlterField(
            model_name='postalcode',
            name='region',
            field=models.ForeignKey(blank=True, null=True, on_delete=cities.models.SET_NULL_OR_CASCADE, related_name='postal_codes', to='cities.Region'),
        ),
        migrations.AlterField(
            model_name='postalcode',
            name='subregion',
            field=models.ForeignKey(blank=True, null=True, on_delete=cities.models.SET_NULL_OR_CASCADE, related_name='postal_codes', to='cities.Subregion'),
        ),
        migrations.AlterField(
            model_name='region',
            name='country',
            field=models.ForeignKey(on_delete=cities.models.SET_NULL_OR_CASCADE, related_name='regions', to=settings.CITIES_COUNTRY_MODEL),
        ),
        migrations.AlterField(
            model_name='subregion',
            name='region',
            field=models.ForeignKey(on_delete=cities.models.SET_NULL_OR_CASCADE, related_name='subregions', to='cities.Region'),
        ),
    ]



from dal.autocomplete import Select2QuerySetView

from cities.contrib.utils import get_cities_models


class PlaceNameStartsWithAutocompleteMixin(object):
    def get_queryset(self):
        qs = self.model.objects.all()

        if self.q:
            qs = qs.filter(Q(name__istartswith=self.q) |
                           Q(alt_names__name__istartswith=self.q))
        else:
            qs = qs[:100]

        return qs


class PlaceNameContainsAutocompleteMixin(object):
    def get_queryset(self):
        qs = self.model.objects.all()

        if self.q:
            qs = qs.filter(Q(name__icontains=self.q) |
                           Q(alt_names__name__icontains=self.q))
        else:
            qs = qs[:100]

        return qs


__all__ = []
for cities_model in get_cities_models():
    model_name = cities_model.__class__._name__

    startswith_autocomplete_name = '{model_name}NameStartsWithAutocomplete'.format(model_name)
    locals()[startswith_autocomplete_name] = type(
        startswith_autocomplete_name,
        (PlaceNameStartsWithAutocompleteMixin,),
        {'model': cities_model})

    contains_autocomplete_name = '{model_name}NameContainsAutocomplete'.format(model_name)
    locals()[contains_autocomplete_name] = type(
        contains_autocomplete_name,
        (PlaceNameContainsAutocompleteMixin,),
        {'model': cities_model})

    __all__.extend([startswith_autocomplete_name, contains_autocomplete_name])



import swapper

from cities.models import (
    Continent, Country, Region, Subregion, City, District, PostalCode,
    AlternativeName)


def get_cities_models():
    return (
        swapper.load_model('cities', 'Continent'),
        swapper.load_model('cities', 'Country'),
        Region,
        Subregion,
        swapper.load_model('cities', 'City'),
        District,
        PostalCode,
        AlternativeName,
    )
